# LibUtil
LibUtil - Biblioteca de utilidades para Python
## Dependencias
Você ira precisa do d Python 3.9 ou superior para usar este pacote.

Este pacote esta disponibilizado no [PyPI](https://pypi.org).

Voce precisa tambem dos seguinte pacotes: setuptools, wheel and twine, que estão disponiveis em [PyPI](https://pypi.org). 

Se vpcê tiver o pip, execute assim:
```
pip install setuptools
pip install wheel
pip install twine
```
## Dependencias para esta versão:
###pacotes:
```
ras>=4.8
cryptography>=36.0.2
pandas>=1.4.1

*   A biblioteca foi construida com estas versões de pacotes. 
    Para versões diferentes cabe mais testes
```

#### Installation
Para efetuar um CLONE deste repositorio em sua maquina use o código abaixo:
```
git clone https://github.com/caiocarneloz/pacotepypi.git
```## Features
- File structure for PyPI packages
- Setup with package informations
- License example